"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var rxjs_1 = require("rxjs");
var OBDConnection_1 = require("./OBDConnection");
/**
 * The wrapper of Socket for Cordova plugin Socket For Cordova.
 */
var CordovaOBDConnection = /** @class */ (function (_super) {
    __extends(CordovaOBDConnection, _super);
    function CordovaOBDConnection() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Open connection to OBD Reader.
     * @returns the observable of opening connection.
     */
    CordovaOBDConnection.prototype.open = function (config) {
        var _this = this;
        var port = config.port, host = config.host;
        var subject = new rxjs_1.Subject();
        this.socket = new Socket();
        this.socket.open(host, port, function () {
            _this.data$ = new rxjs_1.Subject();
            _this.socket.onData = function (data) {
                _this.data$.next(CordovaOBDConnection.unmarshall(data));
            };
            subject.complete();
        }, function (error) { return subject.error(error); });
        return subject.asObservable();
    };
    /**
     * Send a command to OBD Reader.
     * @returns the observable of send operation.
     * The events emitted are ignored, wait for complete (successful) or error (failure).
     */
    CordovaOBDConnection.prototype.send = function (command) {
        var subject = new rxjs_1.Subject();
        this.socket.write(CordovaOBDConnection.marshall(command), function () { return subject.complete(); }, function (error) { return subject.error(error); });
        return subject.asObservable();
    };
    /**
     * Listener for data received from OBD Reader.
     * @returns Observable of data received from OBD Reader.
     */
    CordovaOBDConnection.prototype.onData = function () {
        return this.data$.asObservable();
    };
    /**
     * Close and dispose resources of OBD Reader connection.
     * @returns the observable of close operation.
     * The events emitted are ignored, wait for complete (successful) or error (failure).
     */
    CordovaOBDConnection.prototype.close = function () {
        this.data$.complete();
        this.socket.shutdownWrite();
        setTimeout(this.socket.close);
        return rxjs_1.EMPTY;
    };
    /**
     * Marshall the string data into bytes array.
     * @param data the string data.
     * @returns the bytes array.
     */
    CordovaOBDConnection.marshall = function (data) {
        if (!data) {
            return new Uint8Array(0);
        }
        var bytes = new Uint8Array(data.length);
        for (var i = 0; i < bytes.length; i++) {
            bytes[i] = data.charCodeAt(i);
        }
        return bytes;
    };
    /**
     * Unmarshall the bytes array into data string.
     * @param bytes the bytes array.
     * @returns the string data.
     */
    CordovaOBDConnection.unmarshall = function (bytes) {
        return String.fromCharCode.apply(null, bytes);
    };
    return CordovaOBDConnection;
}(OBDConnection_1.OBDConnection));
exports.CordovaOBDConnection = CordovaOBDConnection;
//# sourceMappingURL=CordovaOBDConnection.js.map