"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var _ = require("lodash");
var OBDData_1 = require("./OBDData");
var fromFields = require("./OBDFields");
/**
 * OBD Event that will be used in the internal part of the rxjs-obd stream.
 */
var OBDEvent = /** @class */ (function () {
    /**
     * Constructor for OBD Events, only rxjs-obd observables should use it.
     *
     * @param _id The event identifier.
     * @param _connection The connection to ELM 327 OBD Reader.
     * @param _subject The subject to be notified only by pluckODBData from rxjs-obd.
     * @param _data The previous ODB data (Optional).
     */
    function OBDEvent(_id, _connection, _subject, _data) {
        if (_data === void 0) { _data = new OBDData_1.OBDData(); }
        this._id = _id;
        this._connection = _connection;
        this._subject = _subject;
        this._data = _data;
        this._data.timestamp = new Date().getTime();
    }
    /**
     * Update the supported PIDs.
     *
     * @param segment The segment.
     * @param value The value.
     */
    OBDEvent.prototype.supportedPIDs = function (segment, value) {
        var _a;
        this._data.supportedPIDs = __assign({}, this._data.supportedPIDs, (_a = {}, _a[segment] = value, _a));
    };
    /**
     * Update a field of the public OBD Data.
     * @param name The field name.
     * @param value the new value of field.
     */
    OBDEvent.prototype.update = function (name, value) {
        var field = fromFields[_.snakeCase(name).toUpperCase()];
        var formatted = field.formatter ? field.formatter(field.unit, value) : value + " " + field.unit;
        var code = field.code, label = field.label, unit = field.unit;
        this._data[name] = { code: code, label: label, unit: unit, value: value, formatted: formatted };
    };
    /**
     * The subject to be notified only by pluckODBData from rxjs-obd.
     */
    OBDEvent.prototype.next = function (data) {
        this._subject.next(data);
    };
    Object.defineProperty(OBDEvent.prototype, "id", {
        /**
         * Return the event id.
         * @returns the event id.
         */
        get: function () {
            return this._id;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OBDEvent.prototype, "connection", {
        /**
         * Return the internal connection connection to be used by rxjs-obd operators only.
         * @returns The connection connection to ELM 327 OBD Reader.
         */
        get: function () {
            return this._connection;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OBDEvent.prototype, "data", {
        /**
         * Return the public data of the rxjs-obd observables.
         * @returns The public data.
         */
        get: function () {
            return this._data;
        },
        enumerable: true,
        configurable: true
    });
    return OBDEvent;
}());
exports.OBDEvent = OBDEvent;
//# sourceMappingURL=OBDEvent.js.map